Description Usage Arguments Value See Also Examples
Perform Parts of Speech tagging and Lemmatisation on 18th-19th century Dutch texts
1 | udpipe_bab(x, tokenizer = c("generic", "basic"), trace = FALSE, ...)
|
x |
a data.frame with columns doc_id and text |
tokenizer |
either 'generic' to use a generic tokenizer provided by R package udpipe or 'basic' to split based on spaces |
trace |
argument passed on to |
... |
passed on to |
a data.frame with tokenised and parts of speech tags and lemma's with columns doc_id, sentence_id, token, lemma, upos, xpos, token_id, term_id, start, end. Note that columns start and end will be all NA values if the 'basic' tokenizer is used
tokenize_simple, udpipe_annotate
1 2 3 4 5 6 7 8 | x <- data.frame(doc_id = c("a", "b"),
text = c("Desen brief sal men bstelen an Janetie Alberts woont in fredrickstadt",
"dit kan Ul op vaders rekeningh setten ende senden"),
stringsAsFactors = FALSE)
anno <- udpipe_bab(x, tokenizer = "generic")
anno
anno <- udpipe_bab(x, tokenizer = "basic")
anno
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.